@@ -4,6 +4,8 @@
 from rdkit import Chem
 from sklearn.base import BaseEstimator, TransformerMixin
 from rdkit.Chem.MolStandardize import rdMolStandardize
+from rdkit.rdBase import BlockLogs
+
 
 class Standardizer(BaseEstimator, TransformerMixin):
     """ Input a list of rdkit mols, output the same list but standardised 
@@ -15,6 +17,7 @@ class Standardizer(BaseEstimator, TransformerMixin):
         return self        
         
     def transform(self, X):
+        block = BlockLogs() # Block all RDkit logging
         arr = []
         for mol in X:
             # Normalizing functional groups
@@ -28,4 +31,6 @@ class Standardizer(BaseEstimator, TransformerMixin):
                 uncharged_parent_clean_mol = uncharger.uncharge(parent_clean_mol)
             # Add to final list
             arr.append(uncharged_parent_clean_mol)
+        
+        del block # Release logging block to previous state
         return(arr)
